summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-09-25 04:55:41 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-09-25 04:55:41 +0000
commit915c2ffc0aa07bb33e09b11b5e2275c034fb5d96 (patch)
tree97c79cd1a1a1d929799d656e2463edce432b9517 /crawl-ref/source/enum.h
parent87df3f8adf2ce93247abaece1b11a10bedd9c44c (diff)
downloadcrawl-ref-915c2ffc0aa07bb33e09b11b5e2275c034fb5d96.tar.gz
crawl-ref-915c2ffc0aa07bb33e09b11b5e2275c034fb5d96.zip
Adapt Zin's old Divine Robustness into Elyvilon's Divine Vigour,
replacing the old Incredible Healing. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@6980 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index e09bb22bae..992ee7fcee 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -84,9 +84,9 @@ enum ability_type
ABIL_ELYVILON_DESTROY_WEAPONS = 219,
ABIL_ELYVILON_LESSER_HEALING = 220, // 220
ABIL_ELYVILON_PURIFICATION,
- ABIL_ELYVILON_HEALING,
+ ABIL_ELYVILON_GREATER_HEALING,
ABIL_ELYVILON_RESTORATION,
- ABIL_ELYVILON_GREATER_HEALING, // 224
+ ABIL_ELYVILON_DIVINE_VIGOUR, // 224
ABIL_LUGONU_ABYSS_EXIT, // 225
ABIL_LUGONU_BEND_SPACE,
ABIL_LUGONU_BANISH,
@@ -151,7 +151,7 @@ enum attribute_type
ATTR_HELD, // caught in a net
ATTR_ABYSS_ENTOURAGE, // maximum number of hostile monsters in
// sight of the player while in the Abyss.
- ATTR_DIVINE_ROBUSTNESS, // strength of Zin's Divine Robustness
+ ATTR_DIVINE_VIGOUR, // strength of Ely's Divine Vigour
ATTR_DIVINE_STAMINA, // strength of Zin's Divine Stamina
ATTR_DIVINE_SHIELD, // strength of TSO's Divine Shield
ATTR_UNIQUE_RUNES,
@@ -1092,7 +1092,7 @@ enum duration_type
DUR_REPEL_MISSILES,
DUR_PRAYER,
DUR_PIETY_POOL, // distribute piety over time
- DUR_DIVINE_ROBUSTNESS, // duration of Zin's Divine Robustness
+ DUR_DIVINE_VIGOUR, // duration of Ely's Divine Vigour
DUR_DIVINE_STAMINA, // duration of Zin's Divine Stamina
DUR_DIVINE_SHIELD, // duration of TSO's Divine Shield
DUR_REGENERATION,